@@ -290,14 +290,14 @@ bool AdBlockRule::matchDomain(const QString &domain) const
     }
 
     if (m_blockedDomains.isEmpty()) {
-        foreach (const QString &d, m_allowedDomains) {
+        for (const QString &d : qAsConst(m_allowedDomains)) {
             if (isMatchingDomain(domain, d)) {
                 return true;
             }
         }
     }
     else if (m_allowedDomains.isEmpty()) {
-        foreach (const QString &d, m_blockedDomains) {
+        for (const QString &d : qAsConst(m_blockedDomains)) {
             if (isMatchingDomain(domain, d)) {
                 return false;
             }
@@ -305,13 +305,13 @@ bool AdBlockRule::matchDomain(const QString &domain) const
         return true;
     }
     else {
-        foreach (const QString &d, m_blockedDomains) {
+        for (const QString &d : qAsConst(m_blockedDomains)) {
             if (isMatchingDomain(domain, d)) {
                 return false;
             }
         }
 
-        foreach (const QString &d, m_allowedDomains) {
+        for (const QString &d : qAsConst(m_allowedDomains)) {
             if (isMatchingDomain(domain, d)) {
                 return true;
             }
@@ -451,7 +451,7 @@ void AdBlockRule::parseFilter()
     // Exception always starts with @@
     if (parsedLine.startsWith(QL1S("@@"))) {
         m_isException = true;
-        parsedLine = parsedLine.mid(2);
+        parsedLine.remove(0, 2);
     }
 
     // Parse all options following $ char
@@ -460,7 +460,7 @@ void AdBlockRule::parseFilter()
         const QStringList options = parsedLine.mid(optionsIndex + 1).split(QL1C(','), QString::SkipEmptyParts);
 
         int handledOptions = 0;
-        foreach (const QString &option, options) {
+        for (const QString &option : options) {
             if (option.startsWith(QL1S("domain="))) {
                 parseDomains(option.mid(7), QL1C('|'));
                 ++handledOptions;
@@ -550,12 +550,12 @@ void AdBlockRule::parseFilter()
             return;
         }
 
-        parsedLine = parsedLine.left(optionsIndex);
+        parsedLine.truncate(optionsIndex);
     }
 
     // Rule is classic regexp
     if (parsedLine.startsWith(QL1C('/')) && parsedLine.endsWith(QL1C('/'))) {
-        parsedLine = parsedLine.mid(1);
+        parsedLine.remove(0, 1);
         parsedLine = parsedLine.left(parsedLine.size() - 1);
 
         m_type = RegExpMatchRule;
@@ -570,7 +570,7 @@ void AdBlockRule::parseFilter()
 
     // Remove starting and ending wildcards (*)
     if (parsedLine.startsWith(QL1C('*'))) {
-        parsedLine = parsedLine.mid(1);
+        parsedLine.remove(0, 1);
     }
 
     if (parsedLine.endsWith(QL1C('*'))) {
@@ -579,7 +579,7 @@ void AdBlockRule::parseFilter()
 
     // We can use fast string matching for domain here
     if (filterIsOnlyDomain(parsedLine)) {
-        parsedLine = parsedLine.mid(2);
+        parsedLine.remove(0, 2);
         parsedLine = parsedLine.left(parsedLine.size() - 1);
 
         m_type = DomainMatchRule;
@@ -631,9 +631,9 @@ void AdBlockRule::parseFilter()
 
 void AdBlockRule::parseDomains(const QString &domains, const QChar &separator)
 {
-    QStringList domainsList = domains.split(separator, QString::SkipEmptyParts);
+    const QStringList domainsList = domains.split(separator, QString::SkipEmptyParts);
 
-    foreach (const QString domain, domainsList) {
+    for (const QString domain : domainsList) {
         if (domain.isEmpty()) {
             continue;
         }
@@ -748,7 +748,7 @@ QList<QStringMatcher> AdBlockRule::createStringMatchers(const QStringList &filte
     QList<QStringMatcher> matchers;
     matchers.reserve(filters.size());
 
-    foreach (const QString &filter, filters) {
+    for (const QString &filter : filters) {
         matchers.append(QStringMatcher(filter, m_caseSensitivity));
     }
 
@@ -790,7 +790,8 @@ bool AdBlockRule::isMatchingRegExpStrings(const QString &url) const
 {
     Q_ASSERT(m_regExp);
 
-    foreach (const QStringMatcher &matcher, m_regExp->matchers) {
+    const auto matchers = m_regExp->matchers;
+    for (const QStringMatcher &matcher : matchers) {
         if (matcher.indexIn(url) == -1)
             return false;
     }
