@@ -42,6 +42,7 @@
 #include "ui_jsprompt.h"
 #include "passwordmanager.h"
 #include "scripts.h"
+#include "ocssupport.h"
 
 #include <iostream>
 
@@ -453,6 +454,10 @@ bool WebPage::acceptNavigationRequest(const QUrl &url, QWebEnginePage::Navigatio
         }
     }
 
+    if (url.scheme() == QL1S("ocs") && OcsSupport::instance()->handleUrl(url)) {
+        return false;
+    }
+
     const bool result = QWebEnginePage::acceptNavigationRequest(url, type, isMainFrame);
 
     if (result) {
